@@ -8,4 +8,10 @@ class PushContractTransactionException(Exception):
     pass
 
 class GetTableException(Exception):
-	pass
\ No newline at end of file
+	pass
+
+class GetBalanceException(Exception):
+    pass
+
+class GetAccountException(Exception):
+    pass
\ No newline at end of file
